Description Usage Arguments Details Value See Also Examples
Estimates the ex-ante Hurst exponent and fractal volatility from option implied volatilities via a decomposition over the term structure. Builds on fractal option pricing of Hu and Oksendal (2003).
1 |
data |
Time series of implied volatilities with columns of different time-to-maturity. |
maturities |
Maturities (in days) of the data columns. If not specified, then maturities are tried to be imported from |
ihurst Estimates the implied Hurst exponent, which can be used as risk-neutral momentum or for sentiment analysis. Methods summary, plot and print are defined for objects of class ivol.
ihurst returns a list object of class "c(ihurst, ivol)". List elements are as follows:
coefficients |
A matrix of estimated Hurst exponents, fractal volatility plus goodness of fit (r2). |
residuals |
The residuals, that is response minus fitted values. |
method |
Underlying estimation method. Currently only " |
call |
The matched call. |
fitted.values |
Regression's fitted values. |
1 2 3 4 5 6 7 8 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.