imom: Implied Moments

Description Usage Arguments Details Value See Also Examples

View source: R/ivol.R

Description

Estimates ex-ante skewness and kurtosis from option implied volatilities over degrees of moneyness. Uses Gram-Chalier expansion.

Usage

1
imom(data, moneyness=NULL)

Arguments

data

Time series of implied volatilities with columns of different moneyness. data can be of any class, as long as it is transformable to a matrix when calling as.matrix().

moneyness

Degrees of moneyness (in percent) of the data columns. If not specified, moneyness is tried to be imported from data's column names.

Details

imom Estimates implied base-volatility, skewness and kurtosis. Can be used as risk-neutral moments. Methods summary, plot and print are defined for objects of class ivol.

Value

imom returns a list object of class "c(imom, ivol)". List elements are as follows:

coefficients

A matrix of estimated implied volatility, skewness, kurtosis plus goodness of fit (r2).

residuals

The residuals, that is response minus fitted values.

method

Underlying estimation method. Currently only "gramchalier" available.

call

The matched call.

fitted.values

Regression's fitted values

See Also

ihurst

Examples

1
2
3
4
5
6
7
8
# estimate implied Moments:

library(ivol)
data(otm)
x <- imom(otm)
summary(x)
plot(x)
coef(x)

ivol documentation built on Sept. 19, 2019, 3 a.m.