Description Usage Arguments Details Value See Also Examples
Estimates ex-ante skewness and kurtosis from option implied volatilities over degrees of moneyness. Uses Gram-Chalier expansion.
1 |
data |
Time series of implied volatilities with columns of different moneyness. |
moneyness |
Degrees of moneyness (in percent) of the data columns. If not specified, moneyness is tried to be imported from |
imom Estimates implied base-volatility, skewness and kurtosis. Can be used as risk-neutral moments. Methods summary, plot and print are defined for objects of class ivol.
imom returns a list object of class "c(imom, ivol)". List elements are as follows:
coefficients |
A matrix of estimated implied volatility, skewness, kurtosis plus goodness of fit (r2). |
residuals |
The residuals, that is response minus fitted values. |
method |
Underlying estimation method. Currently only " |
call |
The matched call. |
fitted.values |
Regression's fitted values |
1 2 3 4 5 6 7 8 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.